Enum Optional

pub enum Optional<T> {
    Set(T),
    Unset(T),
}
A protobuf value from a field that may not be set.

This can be pattern matched with match or if let to determine if the field is set and access the field data.

Two Optionals are equal if they match both presence and the field values.

Variants



Set(T)

The field is set; it is present in the serialized message.

  • For an _opt() accessor, this contains a View<impl Proxied>.
  • For a _mut() accessor, this contains a [PresentField] that can be used to access the current value, convert to Mut, clear presence, or set a new value.


Unset(T)

The field is unset; it is absent in the serialized message.

  • For an _opt() accessor, this contains a View<impl Proxied> with the default value.
  • For a _mut() accessor, this contains an [AbsentField] that can be used to access the default or set a new value.

Implementations

Source

impl<T> Optional<T>

pub fn into_inner(self) -> T

Gets the field value, ignoring whether it was set or not.

pub fn new(val: T, is_set: bool) -> Self

Constructs an Optional<T> with a T value and presence bit.

pub fn into_option(self) -> Option<T>

Converts into an Option of the set value, ignoring any unset value.

pub fn is_set(&self) -> bool

Returns if the field is set.

pub fn is_unset(&self) -> bool

Returns if the field is unset.