EnumDescriptor

Struct EnumDescriptor 

pub struct EnumDescriptor { /* private fields */ }
Dynamic representation of enum type.

Can be used in reflective operations.

Implementations

Source

impl EnumDescriptor

pub fn proto(&self) -> &EnumDescriptorProto

Descriptor objects which defined this enum.

pub fn name(&self) -> &str

Enum name as given in .proto file

pub fn full_name(&self) -> &str

Fully qualified protobuf name of enum

pub fn name_to_package(&self) -> &str

Name relative to the package where the message is declared.

pub fn for_type<E: EnumFull>() -> EnumDescriptor

Get EnumDescriptor object for given enum type

pub fn enclosing_message(&self) -> Option<MessageDescriptor>

Get a message containing this message, or None if this message is declared at file level.

pub fn values<'a>(&'a self) -> impl Iterator<Item = EnumValueDescriptor> + 'a

This enum values

pub fn value_by_name(&self, name: &str) -> Option<EnumValueDescriptor>

Find enum variant by name

pub fn value_by_number(&self, number: i32) -> Option<EnumValueDescriptor>

Find enum variant by number

pub fn value_by_index(&self, index: usize) -> EnumValueDescriptor

Get enum variant by index (as declared in .proto file).

pub fn default_value(&self) -> EnumValueDescriptor

Default enum value (first variant).

pub fn value_by_number_or_default(&self, number: i32) -> EnumValueDescriptor

Find enum variant by number or return default (first) enum value

pub fn is<E: Enum>(&self) -> bool

Check if this enum descriptor corresponds given enum type


let descriptor: EnumDescriptor = Label::enum_descriptor();

assert!(descriptor.is::<Label>())
}