FileDescriptor

Struct FileDescriptor 

pub struct FileDescriptor { /* private fields */ }
Reflection for objects defined in .proto file (messages, enums, etc).

The object is refcounted: clone is shallow.

The equality performs pointer comparison: two clones of the same FileDescriptor objects are equal, but two FileDescriptor objects created from the same FileDescriptorProto objects are not equal.

Implementations

Source

impl FileDescriptor

pub fn name(&self) -> &str

The file name.

pub fn package(&self) -> &str

Protobuf package.

pub fn syntax(&self) -> Syntax

Syntax of current file.

pub fn messages(&self) -> impl Iterator<Item = MessageDescriptor> + '_

Top-level messages.

pub fn enums(&self) -> impl Iterator<Item = EnumDescriptor> + '_

Get top-level enums.

pub fn services(&self) -> impl Iterator<Item = ServiceDescriptor> + '_

Get services defined in .proto file.

pub fn extensions(&self) -> impl Iterator<Item = FieldDescriptor> + '_

Extension fields.

pub fn message_by_package_relative_name( &self, name: &str, ) -> Option<MessageDescriptor>

Find message by name relative to the package.

Only search in the current file, not in any dependencies.

pub fn enum_by_package_relative_name( &self, name: &str, ) -> Option<EnumDescriptor>

Find message by name relative to the package.

Only search in the current file, not in any dependencies.

pub fn message_by_full_name(&self, name: &str) -> Option<MessageDescriptor>

Find message by fully-qualified name.

Only search in the current file, not in any dependencies.

pub fn enum_by_full_name(&self, name: &str) -> Option<EnumDescriptor>

Find enum by name fully-qualified name.

Only search in the current file, not in any dependencies.

pub fn new_dynamic( proto: FileDescriptorProto, dependencies: &[FileDescriptor], ) -> Result<FileDescriptor>

Dynamic message created from FileDescriptorProto without generated files.

pub fn new_dynamic_fds( protos: Vec<FileDescriptorProto>, dependencies: &[FileDescriptor], ) -> Result<Vec<FileDescriptor>>

Create a set of file descriptors from individual file descriptors.

pub fn proto(&self) -> &FileDescriptorProto

.proto data for this file.

pub fn deps(&self) -> &[FileDescriptor]

Direct dependencies of this file.

pub fn public_deps(&self) -> impl Iterator<Item = FileDescriptor> + '_

Subset of dependencies which are public