MessageDescriptor

Struct MessageDescriptor 

pub struct MessageDescriptor { /* private fields */ }
Dynamic representation of message type.

Used for reflection.

Implementations

Source

impl MessageDescriptor

pub fn proto(&self) -> &DescriptorProto

Get underlying DescriptorProto object.

pub fn name(&self) -> &str

Message name as specified in .proto file.

pub fn for_type<M: MessageFull>() -> MessageDescriptor

Get a message descriptor for given message type

pub fn nested_messages(&self) -> impl Iterator<Item = MessageDescriptor> + '_

Messages declared in this messages.

pub fn nested_enums(&self) -> impl Iterator<Item = EnumDescriptor> + '_

Get enums declared in this message.

pub fn enclosing_message(&self) -> Option<MessageDescriptor>

Get a message containing this message, or None if this message is declared at file level.

pub fn file_descriptor(&self) -> &FileDescriptor

FileDescriptor containing this message.

pub fn file_descriptor_proto(&self) -> &FileDescriptorProto

FileDescriptorProto containg this message type

pub fn is_map_entry(&self) -> bool

This message descriptor is a map entry.

pub fn new_instance(&self) -> Box<dyn MessageDyn>

New empty message.

Panics

If this message is a map entry message.

pub fn default_instance(&self) -> Option<&'static dyn MessageDyn>

Shared immutable empty message.

Returns None for dynamic message.

Panics

If this message is a map entry message.

pub fn eq(&self, a: &dyn MessageDyn, b: &dyn MessageDyn) -> bool

Check if two messages equal.

Panics

Is any message has different type than this descriptor.

pub fn full_name(&self) -> &str

Fully qualified protobuf message name

pub fn name_to_package(&self) -> &str

Name relative to the package where the message is declared.

pub fn all_oneofs<'a>(&'a self) -> impl Iterator<Item = OneofDescriptor> + 'a

Nested oneofs including synthetic.

pub fn oneofs<'a>(&'a self) -> impl Iterator<Item = OneofDescriptor> + 'a

Non-synthetic oneofs.

pub fn oneof_by_name(&self, name: &str) -> Option<OneofDescriptor>

Get message oneof by name (not implemented).

pub fn fields<'a>(&'a self) -> impl Iterator<Item = FieldDescriptor> + 'a

Message field descriptors.

pub fn extensions(&self) -> impl Iterator<Item = FieldDescriptor> + '_

Extension fields.

pub fn field_by_name(&self, name: &str) -> Option<FieldDescriptor>

Find message field by protobuf field name

Note: protobuf field name might be different for Rust field name.

pub fn field_by_name_or_json_name<'a>( &'a self, name: &str, ) -> Option<FieldDescriptor>

Find message field by field name or field JSON name

pub fn field_by_number(&self, number: u32) -> Option<FieldDescriptor>

Find message field by field name

pub fn parse_from( &self, is: &mut CodedInputStream<'_>, ) -> Result<Box<dyn MessageDyn>>

Parse message from stream.

pub fn parse_from_reader( &self, reader: &mut dyn Read, ) -> Result<Box<dyn MessageDyn>>

Parse message from reader. Parse stops on EOF or when error encountered.

pub fn parse_from_bytes(&self, bytes: &[u8]) -> Result<Box<dyn MessageDyn>>

Parse message from byte array.