Trait OwnedMessageInterop

pub trait OwnedMessageInterop: SealedInternal { }
Traits related to owned message interop. Note that these trait fns are only available on C++ kernel as upb interop of owned messages requires more work to handle the Arena behavior.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors