Crate protobuf

Crate protobuf 

Re-exports

pub use Singular as ProxiedInRepeated;
pub use crate::__internal::runtime::interop::*;

Modules

__internal
The __internal module is for necessary encapsulation breaks between generated code and the runtime.
prelude
Prelude for the Protobuf Rust API.

Macros

proto
proto! enables the use of Rust struct initialization syntax to create protobuf messages. The macro does its best to try and detect the initialization of submessages, but it is only able to do so while the submessage is being defined as part of the original struct literal. Introducing an expression using () or {} as the value of a field will require another call to this macro in order to return a submessage literal.

Structs

ExtensionId
A unique identifier for an extension field. Values of this type are emitted into the generated code and used to access extension fields.
Map
MapIter
An iterator visiting all key-value pairs in arbitrary order.
MapMut
A mutable proxy of a map field.
MapView
A view of a map field.
ParseError
An error that happened during parsing.
ProtoBytes
ProtoStr
A shared immutable view of a protobuf string field’s contents.
ProtoString
An owned type representing protobuf string field’s contents.
Repeated
A repeated field of T, used as the owned target for Proxied.
RepeatedIter
An iterator over the values inside of a View<Repeated<T>>.
RepeatedMut
Mutates the elements in a repeated field of T.
RepeatedView
Views the elements in a repeated field of T.
SerializeError
An error that happened during serialization.
UnknownEnumValue
An integer value wasn’t known for an enum while converting.
Utf8Error
The bytes were not valid UTF-8.

Enums

ProtoBytesCow
ProtoStringCow

Traits

AsMut
Used to semantically do a cheap “to-mut-reference” conversion. This is implemented on both owned Proxied types as well as mut proxy types.
AsView
Used to semantically do a cheap “to-reference” conversion. This is implemented on both owned Proxied types as well as view and mut proxy types.
Clear
ClearAndParse
CopyFrom
Copies the contents from src into self.
Enum
Implemented by all generated enum types.
IntoMut
Used to turn another ‘borrow’ into a mut proxy.
IntoProxied
A value to Proxied-value conversion that consumes the input value.
IntoView
Used to turn another ‘borrow’ into a view proxy.
MapValue
A trait implemented by types which are allowed as values in maps, which is all Singular types. This trait is distinct from Singular only because of the generic K: MapKey.
MergeFrom
Message
A trait that all generated owned message types implement.
MessageMut
A trait that all generated message muts implement.
MessageType
A trait implemented only by Message types.
MessageView
A trait that all generated message views implement.
MutProxied
A type that can be be accessed through a reference-like proxy.
Parse
Proxied
A type that can be accessed through a reference-like proxy.
Serialize
Singular
Singular types are types which are allowed as a simple field, or in a repeated, or as a map value.
TakeFrom
Moves the contents from src into self.

Functions

message_eq
Message equality definition which may have both false-negatives and false-positives in the face of unknown fields.

Type Aliases

Mut
A proxy type that provides exclusive mutable access to a T, like a &'msg mut T.
View
A proxy type that provides shared access to a T, like a &'msg T.